@@ -1,4 +1,4 @@
-from . import db, dt
+from . import db, dt, scraper
 
 def t():
     return 'works on pypi2'
\ No newline at end of file
