@@ -2,10 +2,10 @@ import mysql.connector
 
 def get(schema, buffered=True, dictionary=False):
     cnx = mysql.connector.connect(
-        user=schema.user,
-        password=schema.pw,
-        host=schema.host,
-        database=schema.db
+        user=schema['user'],
+        password=schema['pw'],
+        host=schema['host'],
+        database=schema['db']
     )
     cur = cnx.cursor(buffered=buffered, dictionary=dictionary)
     return cnx, cur
\ No newline at end of file
